--[[

QuickPlot v1.0 Condensed UI/HUD Compatible (CUIC)

Plots a quick route to the specified sector.
 
Based on QuickJump code by Slime73.

Syntax: /plot sector -- Sector can be a system + sector such as Sedina L2 or just the sector coordinates if you want to quickplot in-system,
                        e.g. arta a1 and a1 will both go to Arta Caelestis A-1 if you are already in Arta.

Bind plot_prompt to a key if you want it to prompt you for a sector when you press a key.

]]

declare('quickplot', quickplot or {})

quickplot.version = '1.0 CUIC'

--START VARS

quickplot.colors = {}
quickplot.colors.WHITE = '\127DDDDDD'
quickplot.colors.RED = '\127FF0000'
quickplot.colors.ORANGE = '\127FFA500'

function quickplot.perror(str)
    print(quickplot.colors.RED .. 'ERROR! ' .. quickplot.colors.WHITE .. '' ..tostring(str))
end

function quickplot.pwarning(str)
    print(quickplot.colors.ORANGE .. 'WARNING! ' .. quickplot.colors.WHITE .. '' ..tostring(str))
end

function quickplot.pinfo(str)
    print(quickplot.colors.WHITE .. '' ..tostring(str))
end


-- END VARS

-- START PLOT SCRIPT

function QuickPlot(sector)
	local sectorid = SectorIDFromLocationStr(sector) or SectorIDFromLocationStr(SystemNames[GetCurrentSystemid()]..' '..sector)
	if not sectorid then
    quickplot.perror('Unknown destination sector.')
		return
	elseif sectorid == GetCurrentSectorid() then
    quickplot.pwarning('No route plotted, start and destination sectors are the same.')
		return
	end
	NavRoute.SetFullRoute{sectorid}
	gkinterface.GKProcessCommand('Activate')
	 	quickplot.pinfo('New route plotted. ('..ShortLocationStr(GetCurrentSectorid())..' -> '..ShortLocationStr(sectorid)..')')
end

-- END PLOT SCRIPT

--START REGISTER COMMAND-EVENT-PROCESS

RegisterUserCommand('plot', function(_,m) QuickPlot(table.concat(m, ' ')) end)

gkinterface.GKProcessCommand('alias plot_prompt \'prompt Plot \'')

--END REGISTER COMMAND-EVENT-PROCESS